@@ -2,13 +2,13 @@ package Iterator::Flex::Common;
 
 # ABSTRACT: Iterator Generators and Adapters
 
-use 5.10.0;
+use v5.28;
 use strict;
 use warnings;
 
 use experimental qw( postderef signatures );
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Exporter 'import';
 
@@ -294,9 +294,6 @@ sub ibuffer ( $iterable, $n = 0, $pars = {} ) {
 
 
 
-
-
-
 
 
 
@@ -705,7 +702,7 @@ Iterator::Flex::Common - Iterator Generators and Adapters
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -961,19 +958,16 @@ See L<Iterator::Flex::Buffer> for more details.
 
   $iterator = iflatten( $iterable, ?\%pars );
 
-Returns an iterator which flattens the elements returned by C<$iterable>.
+For each value that C<$iterable> yields, iterate over it if its an
+iterable, otherwise return it.
 
-=over
+For example,
 
-=item *
+   iflatten( [ iseq(1,3), 4, [ 5,6,7 ], [ [8,9,10] ]  ])
 
-If an element is an array, its contents are returned, one-by-one.
+yields
 
-=item *
-
-If an element is an iterator, it is drained, one element at a time.
-
-=back
+   1, 2, 3, 4, 5, 6, 7, [ 8, 9, 10 ]
 
 See L<Iterator::Flex::Flatten> for more details.
 
@@ -1162,7 +1156,7 @@ The returned iterator supports the following methods:
 
 Construct a pass-through iterator which freezes the input iterator
 after every call to C<next>.  C<CODE> will be passed the frozen state
-(generated by calling C<$iterator->freeze> via C<$_>, with which it
+(generated by calling C<$iterator->freeze> via C<$_>), with which it
 can do as it pleases.
 
 <CODE> I<is> executed when C<$iterator> returns I<undef> (that is,
@@ -1218,8 +1212,6 @@ If all of the iterables support it.
 Restore an iterator that has been frozen.
 See L<Iterator::Flex::Manual::Serialization> for more information.
 
-=head1 INTERNALS
-
   $iterator = ipermute( \@array, ?\%pars );
 
 Returns an iterator which will return a permuted version of C<@array>. The
