@@ -2,11 +2,12 @@ package Iterator::Flex::Cycle;
 
 # ABSTRACT: Array Cycle Iterator Class
 
+use v5.28;
 use strict;
 use warnings;
 use experimental 'signatures';
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Iterator::Flex::Utils ':IterAttrs';
 use Ref::Util;
@@ -147,7 +148,7 @@ Iterator::Flex::Cycle - Array Cycle Iterator Class
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 METHODS
 
@@ -176,8 +177,6 @@ The returned iterator supports the following methods:
 
 =back
 
-=head1 INTERNALS
-
 =head1 SUPPORT
 
 =head2 Bugs
