@@ -2,11 +2,12 @@ package Iterator::Flex::Freeze;
 
 # ABSTRACT:  Freeze an iterator after every next
 
+use v5.28;
 use strict;
 use warnings;
 use experimental 'signatures';
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Iterator::Flex::Factory 'to_iterator';
 use Iterator::Flex::Utils
@@ -159,7 +160,7 @@ Iterator::Flex::Freeze - Freeze an iterator after every next
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 METHODS
 
@@ -169,7 +170,7 @@ version 0.31
 
 Construct a pass-through iterator which freezes the input iterator
 after every call to C<next>.  C<$coderef> will be passed the frozen state
-(generated by calling C<$iterator->freeze> via C<$_>, with which it
+(generated by calling C<$iterator->freeze> via C<$_>), with which it
 can do as it pleases.
 
 <$coderef> I<is> executed when C<$iterator> is exhausted.
@@ -193,8 +194,6 @@ If C<$iterator> provides a C<prev> method.
 
 =back
 
-=head1 INTERNALS
-
 =head1 SUPPORT
 
 =head2 Bugs
