@@ -2,11 +2,12 @@ package Iterator::Flex::Method;
 
 # ABSTRACT: Compartmentalize Iterator::Flex::Method::Maker
 
+use v5.28;
 use strict;
 use warnings;
 use experimental 'signatures';
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 # Package::Variant based modules generate constructor functions
 # dynamically when those modules are imported.  However, loading the
@@ -74,9 +75,7 @@ Iterator::Flex::Method - Compartmentalize Iterator::Flex::Method::Maker
 
 =head1 VERSION
 
-version 0.31
-
-=head1 INTERNALS
+version 0.32
 
 =for Pod::Coverage make_variant_package_name
   make_variant
