@@ -2,10 +2,11 @@ package Iterator::Flex::Role::Next::ClosedSelf;
 
 # ABSTRACT: Role for closure iterator which closes over self
 
+use v5.28;
 use strict;
 use warnings;
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Ref::Util;
 use Scalar::Util;
@@ -64,7 +65,7 @@ Iterator::Flex::Role::Next::ClosedSelf - Role for closure iterator which closes
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 METHODS
 
@@ -74,8 +75,6 @@ version 0.31
 
    $iterator->next;
 
-=head1 INTERNALS
-
 =head1 SUPPORT
 
 =head2 Bugs
