@@ -1,11 +1,12 @@
 package Iterator::Flex::Role::Reset::Closure;
 
-# ABSTRACT: Implement C<reset> as a closure stored in the registry
+# ABSTRACT: Implement reset as a closure stored in the registry
 
+use v5.28;
 use strict;
 use warnings;
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Scalar::Util;
 use List::Util;
@@ -59,11 +60,11 @@ __END__
 
 =head1 NAME
 
-Iterator::Flex::Role::Reset::Closure - Implement C<reset> as a closure stored in the registry
+Iterator::Flex::Role::Reset::Closure - Implement reset as a closure stored in the registry
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 METHODS
 
@@ -75,8 +76,6 @@ version 0.31
 
 Resets the iterator to its initial value.
 
-=head1 INTERNALS
-
 =head1 SUPPORT
 
 =head2 Bugs
