@@ -2,10 +2,11 @@ package Iterator::Flex::Role::State;
 
 # ABSTRACT: abstract interface role for State
 
+use v5.28;
 use strict;
 use warnings;
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Role::Tiny;
 
@@ -35,9 +36,7 @@ Iterator::Flex::Role::State - abstract interface role for State
 
 =head1 VERSION
 
-version 0.31
-
-=head1 INTERNALS
+version 0.32
 
 =head1 SUPPORT
 
